@@ -7,7 +7,6 @@ use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 use tracing::trace;
 
 use self::scope::Scope;
-use super::rename_map::RenameMap;
 
 mod scope;
 
@@ -19,14 +18,15 @@ pub(super) struct Analyzer {
 
 impl Analyzer {
     pub(super) fn into_rename_map(mut self, preserved: &FxHashSet<Id>) -> AHashMap<Id, JsWord> {
-        let mut map = RenameMap::default();
+        let mut map = Default::default();
 
         self.scope.prepare_renaming();
 
         let preserved_symbols = preserved.iter().cloned().map(|v| v.0).collect();
-        self.scope.rename(&mut map, preserved, &preserved_symbols);
+        self.scope
+            .rename(&mut map, &Default::default(), preserved, &preserved_symbols);
 
-        map.into_map()
+        map
     }
 
     fn add_decl(&mut self, id: Id) {
